
This is a **richtext widget** for `yafowil 
<http://pypi.python.org/pypi/yafowil>`_ 

It is based on XING's `wysihtml5 <https://github.com/xing/wysihtml5>`_
editor with optionally `bootstrap-wysihtml5 <https://github.com/jhollingworth/bootstrap-wysihtml5>`_ integration.

- `Documentation <http://docs.yafowil.info/en/latest/blueprints.html#wysihtml5>`_
- `DEMO - see it Live <http://demo.yafowil.info/++widget++yafowil.widget.wysihtml5/index.html>`_

Note
====
For the Bootstrap integration, you will need yafowil.bootstrap or another
Twitter-Bootstrap integration. This packages does not register the Bootstrap
base files.

Source Code
===========

The sources are in a GIT DVCS with its main branches at
`github <http://github.com/bluedynamics/yafowil.widget.wysihtml5>`_.

We'd be happy to see many forks and pull-requests to make YAFOWIL even better.


Contributors
============

- Johannes Raggam <johannes [at] raggam [dot] co [dot] at>
